%global binname qt5-virt-manager

Name:           qt-virt-manager
Version:        0.43.70
Release:        2%{?dist}
Summary:        Qt Virtual Machine Manager

License:        GPLv2+
URL:            http://f1ash.github.io/%{name}
Source0:        https://github.com/F1ash/%{name}/archive/%{version}.tar.gz

# be compatible with prior subpackages
Provides:       virt-manager-qt4 = %{version}-%{release}
Provides:       virt-manager-qt5 = %{version}-%{release}
Obsoletes:      virt-manager-qt4 <= 0.25.47
Obsoletes:      virt-manager-qt5 <= 0.25.47

Requires:       hicolor-icon-theme

Requires:       libvirt
Requires:       qtermwidget-qt5 >= 0.6.0-2
Requires:       qt-remote-viewer

# for use qemu-kvm (more useful)
Requires:       qemu-kvm

# for use SPICE viewer
Requires:       spice-vdagent

# optional runtime extensions
%if 0%{?fedora}
# for scrubbing
Suggests:       scrub
# netcat for ssh-transported remote connections
Suggests:       nc
# for use VNC client with tls
Suggests:       gnutls
%endif

BuildRequires:  qt5-qtbase-devel
BuildRequires:  qt5-qtmultimedia-devel
BuildRequires:  qt5-qtsvg-devel
BuildRequires:  qtermwidget-qt5-devel >= 0.6.0-2

BuildRequires:  libvirt-devel
BuildRequires:  glibc-headers
BuildRequires:  desktop-file-utils
BuildRequires:  cmake
BuildRequires:  glib2-devel
BuildRequires:  spice-protocol
BuildRequires:  spice-glib-devel
BuildRequires:  libvncserver-devel
%if %{?fedora}>=24
BuildRequires:  libcacard-devel
%endif

%description
Qt Virtual Machine Manager provides a graphical tool for
administering virtual machines for QEMU/KVM, Xen, LXC, OpenVZ,
VBox, VMWare, HyperV, IBM PowerVM, Bhyve virtual machines
and other Virtual Entities.
Start, stop, add or remove virtual devices, connect to a
graphical or serial console, and see resource usage
statistics for existing VMs on local or remote machines.
Uses libvirt as the back-end management API.
Uses Spice/VNC viewers for control.

%package -n     qt-remote-viewer
Summary:        Qt Remote Viewer

%description -n qt-remote-viewer
Qt viewer for remote access to Spice/VNC desktops.


%prep
%setup -q

%build
mkdir -p %{_target_platform}
pushd %{_target_platform}
%cmake -DBUILD_QT_VERSION=5 \
%if %{?fedora}>=24
 -DWITH_LIBCACARD=1 \
%endif
 ..
popd
%make_build -C %{_target_platform}

%install
%make_install -C %{_target_platform}

%check
desktop-file-validate %{buildroot}/%{_datadir}/applications/%{binname}.desktop
desktop-file-validate %{buildroot}/%{_datadir}/applications/qt5-remote-viewer.desktop


%post
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%files
%license LICENSE Licenses
%doc README.md Changelog
%{_bindir}/%{binname}
%{_datadir}/applications/%{binname}.desktop
%{_datadir}/%{binname}/
%{_datadir}/icons/hicolor/256x256/apps/virtual-engineering.png

%files -n       qt-remote-viewer
%license LICENSE
%{_bindir}/qt5-remote-viewer
%{_datadir}/applications/qt5-remote-viewer.desktop
%{_datadir}/icons/hicolor/256x256/apps/remote-desktop-viewer.png


%changelog
* Sat May 13 2017 Fl@sh <kaperang07@gmail.com> - 0.43.70-2
- return R and BR to previous state;
- release updated;

* Fri May 12 2017 Fl@sh <kaperang07@gmail.com> - 0.43.70-1
- enhanced %%description;
- version updated;

* Wed Apr 19 2017 Christian Dersch <lupinix@mailbox.org> - 0.42.67-3
- rebuilt for qtermwidget 0.7.1

* Mon Mar 20 2017 Fl@sh <kaperang07@gmail.com> - 0.42.67-2
- release updated with fixed code for build into f24/25;

* Mon Mar 20 2017 Fl@sh <kaperang07@gmail.com> - 0.42.67-1
- enhanced %%description;
- version updated;

* Tue Feb 14 2017 Rex Dieter <rdieter@fedoraproject.org> - 0.39.60-4
- rebuild (libvncserver)

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.39.60-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Jan 30 2017 Fl@sh <kaperang07@gmail.com> - 0.39.60-2
- enhanced %%description;
- version updated;

* Wed Oct 26 2016 Fl@sh <kaperang07@gmail.com> - 0.37.57-2
- new release
- fixed spelling, obsolete-not-provided, explicit-lib-dependency errors

* Wed Oct 26 2016 Fl@sh <kaperang07@gmail.com> - 0.37.57-1
- new version
- add qt-remote-viewer subpackage

* Fri Jul 29 2016 Raphael Groner <projects.rg@smart.ms> - 0.34.50-1
- new version
- add support for VNC

* Wed Jun 01 2016 Raphael Groner <projects.rg@smart.ms> - 0.27.50-4
- remove broken dependency to nc6
- add options as Suggests
- remove useless R: xorg-x11-drv-qxl

* Fri May 13 2016 Raphael Groner <projects.rg@smart.ms> - 0.27.50-3
- rebuilt

* Wed May 11 2016 Raphael Groner <projects.rg@smart.ms> - 0.27.50-2
- add R: xorg-x11-drv-qxl

* Wed May 11 2016 Raphael Groner <projects.rg@smart.ms> - 0.27.50-1
- new version, qt5 only

* Sun Mar 20 2016 Fl@sh <kaperang07@gmail.com> - 0.25.47-1
- fixed RHBZ #1319386;
- version updated;
 
* Thu Mar 10 2016 Fl@sh <kaperang07@gmail.com> - 0.22.45-1
- changed URL, BR and %%build for libcacard using after F23 release;
- version updated;

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.22.42-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Dec 17 2015 Rex Dieter <rdieter@fedoraproject.org> 0.22.42-2
- BR: qt5-qtmultimedia-devel (#1292612)

* Thu Dec 17 2015 Raphael Groner <projects.rg@smart.ms> - 0.22.42-1
- new version

* Mon Oct 12 2015 Raphael Groner <projects.rg@smart.ms> - 0.16.38-3
- rename sub packages

* Mon Oct 12 2015 Raphael Groner <projects.rg@smart.ms> - 0.16.38-2
- adjust for review, based on upstream's proposal
- use suffixed binaries

* Sun Sep 20 2015 Fl@sh <kaperang07@gmail.com> - 0.16.38-1
- improved spec for using SPICE, Qemu/KVM, ssh connections;
- version updated;

* Tue Jun 23 2015 Fl@sh <kaperang07@gmail.com> - 0.12.28-1
- version updated;

* Wed May 13 2015 Fl@sh <kaperang07@gmail.com> - 0.10.25-1
- changed %%files for desktop icon;
- version updated;

* Thu Apr 23 2015 Fl@sh <kaperang07@gmail.com> - 0.10.21-1
- version updated;
- clear %%changelog;
